summaryrefslogtreecommitdiffstats
path: root/ash
diff options
context:
space:
mode:
authornkostylev@chromium.org <nkostylev@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-01-16 14:35:38 +0000
committernkostylev@chromium.org <nkostylev@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-01-16 14:35:38 +0000
commita2774c38a3e7dea6bcf07b2a05c1a787b0dacbef (patch)
tree89cb3930f4d67b1f397f5fa6f3d377a9f31d2133 /ash
parent479597bd11dddad114485bbe1f8f4fd0c8f4a01e (diff)
downloadchromium_src-a2774c38a3e7dea6bcf07b2a05c1a787b0dacbef.zip
chromium_src-a2774c38a3e7dea6bcf07b2a05c1a787b0dacbef.tar.gz
chromium_src-a2774c38a3e7dea6bcf07b2a05c1a787b0dacbef.tar.bz2
Locally managed accounts (backend)
BUG=167661 TBR=sadrul Review URL: https://codereview.chromium.org/11601006 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@177151 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash')
-rw-r--r--ash/system/user/login_status.h15
-rw-r--r--ash/system/user/tray_user.cc1
2 files changed, 9 insertions, 7 deletions
diff --git a/ash/system/user/tray_user.cc b/ash/system/user/tray_user.cc
index fad3e09..de5f7cb 100644
--- a/ash/system/user/tray_user.cc
+++ b/ash/system/user/tray_user.cc
@@ -592,6 +592,7 @@ void TrayUser::UpdateAfterLoginStatusChange(user::LoginStatus status) {
case user::LOGGED_IN_USER:
case user::LOGGED_IN_OWNER:
case user::LOGGED_IN_PUBLIC:
+ case user::LOGGED_IN_LOCALLY_MANAGED:
avatar_->SetImage(
ash::Shell::GetInstance()->system_tray_delegate()->GetUserImage(),
gfx::Size(kUserIconSize, kUserIconSize));
diff --git a/ash/system/user/login_status.h b/ash/system/user/login_status.h
index 7cbfdbc..005e117 100644
--- a/ash/system/user/login_status.h
+++ b/ash/system/user/login_status.h
@@ -11,13 +11,14 @@ namespace ash {
namespace user {
enum LoginStatus {
- LOGGED_IN_LOCKED, // A user has locked the screen.
- LOGGED_IN_USER, // A normal user is logged in.
- LOGGED_IN_OWNER, // The owner of the device is logged in.
- LOGGED_IN_GUEST, // A guest is logged in (i.e. incognito)
- LOGGED_IN_KIOSK, // Is in kiosk mode.
- LOGGED_IN_PUBLIC, // A public account is logged in.
- LOGGED_IN_NONE, // Not logged in.
+ LOGGED_IN_LOCKED, // A user has locked the screen.
+ LOGGED_IN_USER, // A normal user is logged in.
+ LOGGED_IN_OWNER, // The owner of the device is logged in.
+ LOGGED_IN_GUEST, // A guest is logged in (i.e. incognito)
+ LOGGED_IN_KIOSK, // Is in kiosk mode.
+ LOGGED_IN_PUBLIC, // A public account is logged in.
+ LOGGED_IN_LOCALLY_MANAGED, // A locally managed user is logged in.
+ LOGGED_IN_NONE, // Not logged in.
};
string16 GetLocalizedSignOutStringForStatus(LoginStatus status, bool multiline);